---
name: Requirement
about: Confirmed requirement for the project
title: "[USR001] - Requirement"
labels: ''
assignees: ''

---

**Mandatory:** yes/no

**Requirement description:**
A clear and concise description of the requirement

**Additional context**
Add any other context or technical information relevant to the requirement
